<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>showdesktop</name>
    <message>
        <source>show desktop</source>
        <translation>显示桌面</translation>
    </message>
</context>
</TS>